@@ -7,20 +7,34 @@ string2formula <- function(x) {
 check_na <- function(data, step) {
   na_cols <- vapply(data, function(x) any(is.na(x)), FUN.VALUE = logical(1))
   if (any(na_cols)) {
-    rlang::abort(paste0(
-      "`", step,
-      "` cannot have any missing values. NAs found ind: ",
-      paste(names(na_cols), collapse = ", "), "."
+    cols <- paste(names(na_cols)[na_cols], collapse = ", ")
+    rlang::abort(glue(
+      "`{step}` cannot have any missing values. NAs found ind: {cols}."
     ))
   }
 }
 
 check_2_levels_only <- function(data, col_name) {
   if (length(levels(data[[col_name]])) != 2) {
-    rlang::abort(paste0("`", col_name, "`` must only have 2 levels."))
+    rlang::abort(glue("`{col_name}` must only have 2 levels."))
   }
 }
 
+check_numeric <- function(dat) {
+  all_good <- vapply(dat, is.numeric, logical(1))
+  label <- "numeric"
+
+  if (!all(all_good)) {
+    rlang::abort("All columns for this function should be numeric.")
+  }
+  invisible(all_good)
+}
+
+check_column_factor <- function(data, column) {
+  if (!is.factor(data[[column]])) {
+    rlang::abort(glue("`{column}` should be a factor variable."))
+  }
+}
 
 na_splice <- function(new_data, synthetic_data, object) {
   non_predictor <- setdiff(names(new_data), c(object$column, object$predictors))
@@ -46,3 +60,9 @@ na_splice <- function(new_data, synthetic_data, object) {
 
   res[, names(new_data)]
 }
+
+#https://stackoverflow.com/questions/2547402/how-to-find-the-statistical-mode
+Mode <- function(x) {
+  ux <- unique(x)
+  ux[which.max(tabulate(match(x, ux)))]
+}
